pub struct AuthorityContactsBuilder {
v3idents: Option<Vec<RsaIdentity>>,
uploads: Option<Vec<Vec<SocketAddr>>>,
downloads: Option<Vec<Vec<SocketAddr>>>,
votes: Option<Vec<Vec<SocketAddr>>>,
}Expand description
A builder to create an instance of AuthorityContacts.
Fields
v3idents: Option<Vec<RsaIdentity>>In-progress value for v3idents.
uploads: Option<Vec<Vec<SocketAddr>>>In-progress value for uploads.
downloads: Option<Vec<Vec<SocketAddr>>>In-progress value for downloads.
votes: Option<Vec<Vec<SocketAddr>>>In-progress value for votes.
Implementations
Sourceimpl AuthorityContactsBuilder
impl AuthorityContactsBuilder
Sourcepub fn build(&self) -> Result<AuthorityContacts, ConfigBuildError>
pub fn build(&self) -> Result<AuthorityContacts, ConfigBuildError>
Try to construct a new AuthorityContacts from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl AuthorityContactsBuilder
impl AuthorityContactsBuilder
Sourcepub fn v3idents(&mut self) -> &mut Vec<RsaIdentity>
pub fn v3idents(&mut self) -> &mut Vec<RsaIdentity>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_v3idents(&mut self, list: Vec<RsaIdentity>)
pub fn set_v3idents(&mut self, list: Vec<RsaIdentity>)
Set the whole list (overriding the default)
Sourcepub fn opt_v3idents(&self) -> &Option<Vec<RsaIdentity>>
pub fn opt_v3idents(&self) -> &Option<Vec<RsaIdentity>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_v3idents_mut(&mut self) -> &mut Option<Vec<RsaIdentity>>
pub fn opt_v3idents_mut(&mut self) -> &mut Option<Vec<RsaIdentity>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.
Sourcepub fn uploads(&mut self) -> &mut Vec<Vec<SocketAddr>>
pub fn uploads(&mut self) -> &mut Vec<Vec<SocketAddr>>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_uploads(&mut self, list: Vec<Vec<SocketAddr>>)
pub fn set_uploads(&mut self, list: Vec<Vec<SocketAddr>>)
Set the whole list (overriding the default)
Sourcepub fn opt_uploads(&self) -> &Option<Vec<Vec<SocketAddr>>>
pub fn opt_uploads(&self) -> &Option<Vec<Vec<SocketAddr>>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_uploads_mut(&mut self) -> &mut Option<Vec<Vec<SocketAddr>>>
pub fn opt_uploads_mut(&mut self) -> &mut Option<Vec<Vec<SocketAddr>>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.
Sourcepub fn downloads(&mut self) -> &mut Vec<Vec<SocketAddr>>
pub fn downloads(&mut self) -> &mut Vec<Vec<SocketAddr>>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_downloads(&mut self, list: Vec<Vec<SocketAddr>>)
pub fn set_downloads(&mut self, list: Vec<Vec<SocketAddr>>)
Set the whole list (overriding the default)
Sourcepub fn opt_downloads(&self) -> &Option<Vec<Vec<SocketAddr>>>
pub fn opt_downloads(&self) -> &Option<Vec<Vec<SocketAddr>>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_downloads_mut(&mut self) -> &mut Option<Vec<Vec<SocketAddr>>>
pub fn opt_downloads_mut(&mut self) -> &mut Option<Vec<Vec<SocketAddr>>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.
Sourcepub fn votes(&mut self) -> &mut Vec<Vec<SocketAddr>>
pub fn votes(&mut self) -> &mut Vec<Vec<SocketAddr>>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_votes(&mut self, list: Vec<Vec<SocketAddr>>)
pub fn set_votes(&mut self, list: Vec<Vec<SocketAddr>>)
Set the whole list (overriding the default)
Sourcepub fn opt_votes(&self) -> &Option<Vec<Vec<SocketAddr>>>
pub fn opt_votes(&self) -> &Option<Vec<Vec<SocketAddr>>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_votes_mut(&mut self) -> &mut Option<Vec<Vec<SocketAddr>>>
pub fn opt_votes_mut(&mut self) -> &mut Option<Vec<Vec<SocketAddr>>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.