#[non_exhaustive]pub struct DirTolerance { /* private fields */ }Expand description
Configuration for how much much to extend the official tolerances of our directory information.
Because of possible clock skew, and because we want to tolerate possible failures of the directory authorities to reach a consensus, we want to consider a directory to be valid for a while before and after its official range of validity.
TODO: Remove the Default because it is too tightly bound to a client.
Implementations
Sourceimpl DirTolerance
impl DirTolerance
Sourcepub fn builder() -> DirToleranceBuilder
pub fn builder() -> DirToleranceBuilder
Return a new [DirTolerance Builder] to construct an instance of this type.
Sourceimpl DirTolerance
impl DirTolerance
Sourcepub fn pre_valid_tolerance(&self) -> Duration
pub fn pre_valid_tolerance(&self) -> Duration
For how long before a directory document is valid should we accept it?
Having a nonzero value here allows us to tolerate a little clock skew.
Defaults to 1 day.
Sourcepub fn post_valid_tolerance(&self) -> Duration
pub fn post_valid_tolerance(&self) -> Duration
For how long after a directory document is valid should we consider it usable?
Having a nonzero value here allows us to tolerate a little clock skew, and makes us more robust to temporary failures for the directory authorities to reach consensus.
Defaults to 3 days (per prop212).
Sourceimpl DirTolerance
impl DirTolerance
Sourcepub fn extend_tolerance<B>(
&self,
timebound: TimerangeBound<B>,
) -> TimerangeBound<B>
pub fn extend_tolerance<B>( &self, timebound: TimerangeBound<B>, ) -> TimerangeBound<B>
Return a new TimerangeBound that extends the validity interval of
timebound according to this configuration.
Sourcepub fn extend_lifetime(&self, lifetime: &Lifetime) -> Lifetime
pub fn extend_lifetime(&self, lifetime: &Lifetime) -> Lifetime
Return a new consensus Lifetime that extends the validity intervals
of lifetime according to this configuration.