DownloadScheduleConfigBuilder

Struct DownloadScheduleConfigBuilder 

pub struct DownloadScheduleConfigBuilder { /* private fields */ }
A builder to create an instance of DownloadScheduleConfig.

Implementations

Source

impl DownloadScheduleConfigBuilder

pub fn retry_bootstrap(&mut self) -> &mut DownloadScheduleBuilder

Return a mutable reference to the inner builder for retry_bootstrap.

retry_bootstrap

Top-level configuration for how to retry our initial bootstrap attempt.

pub fn retry_consensus(&mut self) -> &mut DownloadScheduleBuilder

Return a mutable reference to the inner builder for retry_consensus.

retry_consensus

Configuration for how to retry a consensus download.

pub fn retry_certs(&mut self) -> &mut DownloadScheduleBuilder

Return a mutable reference to the inner builder for retry_certs.

retry_certs

Configuration for how to retry an authority cert download.

pub fn retry_microdescs(&mut self) -> &mut DownloadScheduleBuilder

Return a mutable reference to the inner builder for retry_microdescs.

retry_microdescs

Configuration for how to retry a microdescriptor download.

Source

impl DownloadScheduleConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<DownloadScheduleConfig, ConfigBuildError>

Try to construct a new DownloadScheduleConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.