NetworkConfig

Struct NetworkConfig 

#[non_exhaustive]
pub struct NetworkConfig { /* private fields */ }
Configuration information about the Tor network itself; used as part of Arti’s configuration.

This type is immutable once constructed. To make one, use NetworkConfigBuilder, or deserialize it from a string.

Implementations

Source

impl NetworkConfig

pub fn builder() -> NetworkConfigBuilder

Return a new [NetworkConfig Builder] to construct an instance of this type.

Source

impl NetworkConfig

pub fn fallback_caches(&self) -> &FallbackList

List of locations to look in when downloading directory information, if we don’t actually have a directory yet.

(If we do have a cached directory, we use directory caches listed there instead.)

This section can be changed in a running Arti client. Doing so will affect future download attempts only.

The default is to use a set of compiled-in fallback directories, whose addresses and public keys are shipped as part of the Arti source code.

pub fn authorities(&self) -> &AuthorityContacts

List of directory authorities which we expect to perform various operations affecting the overall Tor network.

(If none are specified, we use a default list of authorities shipped with Arti.)

This section cannot be changed in a running Arti client.

The default is to use a set of compiled-in authorities, whose identities and public keys are shipped as part of the Arti source code.