NetworkConfigBuilder

Struct NetworkConfigBuilder 

pub struct NetworkConfigBuilder { /* private fields */ }
A builder to create an instance of NetworkConfig.

Implementations

Source

impl NetworkConfigBuilder

pub fn authorities(&mut self) -> &mut AuthorityContactsBuilder

Return a mutable reference to the inner builder for authorities.

authorities

List of directory authorities which we expect to perform various operations affecting the overall Tor network.

(If none are specified, we use a default list of authorities shipped with Arti.)

This section cannot be changed in a running Arti client.

The default is to use a set of compiled-in authorities, whose identities and public keys are shipped as part of the Arti source code.

Source

impl NetworkConfigBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<NetworkConfig, ConfigBuildError>

Try to construct a new NetworkConfig from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.

Source

impl NetworkConfigBuilder

pub fn fallback_caches(&mut self) -> &mut Vec<FallbackDirBuilder>

Access the being-built list (resolving default)

If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.

pub fn set_fallback_caches(&mut self, list: Vec<FallbackDirBuilder>)

Set the whole list (overriding the default)

pub fn opt_fallback_caches(&self) -> &Option<Vec<FallbackDirBuilder>>

Inspect the being-built list (with default unresolved)

If the list has not yet been set, or accessed, &None is returned.

pub fn opt_fallback_caches_mut( &mut self, ) -> &mut Option<Vec<FallbackDirBuilder>>

Mutably access the being-built list (with default unresolved)

If the list has not yet been set, or accessed, &mut None is returned.