#[non_exhaustive]pub enum DirBackendPluginError {
UriNotHandledByPlugin,
Bug(Bug),
}Expand description
An error that occurred while trying to handle a request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UriNotHandledByPlugin
The request was one which this plugin doesn’t know how to handle.
Bug(Bug)
An internal error occurred while trying to handle the request.