FallbackDirBuilder

Struct FallbackDirBuilder 

pub struct FallbackDirBuilder { /* private fields */ }
A builder to create an instance of FallbackDir.

Implementations

Source

impl FallbackDirBuilder

pub fn rsa_identity(&mut self, val: RsaIdentity) -> &mut Self

Provide a value for rsa_identity.

If no value is provided for rsa_identity, build will fail with an error.

rsa_identity

RSA identity for the directory relay

pub fn ed_identity(&mut self, val: Ed25519Identity) -> &mut Self

Provide a value for ed_identity.

If no value is provided for ed_identity, build will fail with an error.

ed_identity

Ed25519 identity for the directory relay

Source

impl FallbackDirBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<FallbackDir, ConfigBuildError>

Try to construct a new FallbackDir from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.

Source

impl FallbackDirBuilder

pub fn orports(&mut self) -> &mut Vec<SocketAddr>

Access the being-built list (resolving default)

If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.

pub fn set_orports(&mut self, list: Vec<SocketAddr>)

Set the whole list (overriding the default)

pub fn opt_orports(&self) -> &Option<Vec<SocketAddr>>

Inspect the being-built list (with default unresolved)

If the list has not yet been set, or accessed, &None is returned.

pub fn opt_orports_mut(&mut self) -> &mut Option<Vec<SocketAddr>>

Mutably access the being-built list (with default unresolved)

If the list has not yet been set, or accessed, &mut None is returned.