pub struct FallbackListBuilder { /* private fields */ }Expand description
Wrapper struct to help derive_builder find the right types and methods
This struct is not part of the configuration API. Refer to the containing structures for information on how to build the config.
Implementations
Sourceimpl FallbackListBuilder
impl FallbackListBuilder
Sourcepub fn build(&self) -> Result<FallbackList, ConfigBuildError>
pub fn build(&self) -> Result<FallbackList, ConfigBuildError>
Resolve this list to a list of built items.
If the value is still the Default,
a built-in default list will be built and returned;
otherwise each applicable item will be built,
and the results collected into a single built list.
Sourcepub fn access(&mut self) -> &mut Vec<FallbackDirBuilder>
pub fn access(&mut self) -> &mut Vec<FallbackDirBuilder>
Resolve the list to the default if necessary and then return &mut Vec
Sourcepub fn access_opt(&self) -> &Option<Vec<FallbackDirBuilder>>
pub fn access_opt(&self) -> &Option<Vec<FallbackDirBuilder>>
Resolve the list to the default if necessary and then return &mut Vec
Sourcepub fn access_opt_mut(&mut self) -> &mut Option<Vec<FallbackDirBuilder>>
pub fn access_opt_mut(&mut self) -> &mut Option<Vec<FallbackDirBuilder>>
Resolve the list to the default if necessary and then return &mut Vec