pub struct DownloadSchedule {
attempts: NonZeroU32,
initial_delay: Duration,
parallelism: NonZeroU8,
}Expand description
Configuration for how many times to retry a download, with what frequency.
Fields
attempts: NonZeroU32How many attempts to make before giving up?
initial_delay: DurationThe amount of time to delay after the first failure, and a lower-bound for future delays.
parallelism: NonZeroU8When we want to download a bunch of these at a time, how many attempts should we try to launch at once?
Implementations
Sourceimpl DownloadSchedule
impl DownloadSchedule
Sourcepub fn builder() -> DownloadScheduleBuilder
pub fn builder() -> DownloadScheduleBuilder
Return a new [DownloadSchedule Builder] to construct an instance of this type.
Sourceimpl DownloadSchedule
impl DownloadSchedule
Sourcepub fn attempts(&self) -> impl Iterator<Item = u32> + use<>
pub fn attempts(&self) -> impl Iterator<Item = u32> + use<>
Return an iterator to use over all the supported attempts for this configuration.
Sourcepub fn n_attempts(&self) -> u32
pub fn n_attempts(&self) -> u32
Return the number of times that we’re supposed to retry, according to this DownloadSchedule.
Sourcepub fn parallelism(&self) -> u8
pub fn parallelism(&self) -> u8
Return the number of parallel attempts that we’re supposed to launch, according to this DownloadSchedule.
Sourcepub fn schedule(&self) -> RetryDelay
pub fn schedule(&self) -> RetryDelay
Return a RetryDelay object for this configuration.
If the initial delay is longer than 32