DownloadScheduleBuilder

Struct DownloadScheduleBuilder 

pub struct DownloadScheduleBuilder { /* private fields */ }
A builder to create an instance of DownloadSchedule.

Implementations

Source

impl DownloadScheduleBuilder

pub fn attempts(&mut self, val: impl PossiblyBoundsChecked<u32>) -> &mut Self

Provide a value for attempts.

If no value is provided for attempts, build will use Default::default(). For convenience, this function accepts both u32 and NonZero<u32>.

attempts

How many attempts to make before giving up?

pub fn initial_delay(&mut self, val: Duration) -> &mut Self

Provide a value for initial_delay.

If no value is provided for initial_delay, build will use Default::default().

initial_delay

The amount of time to delay after the first failure, and a lower-bound for future delays.

pub fn parallelism(&mut self, val: impl PossiblyBoundsChecked<u8>) -> &mut Self

Provide a value for parallelism.

If no value is provided for parallelism, build will use Default::default(). For convenience, this function accepts both u8 and NonZero<u8>.

parallelism

When we want to download a bunch of these at a time, how many attempts should we try to launch at once?

Source

impl DownloadScheduleBuilder

pub fn new() -> Self

Return a new builder object.

pub fn build(&self) -> Result<DownloadSchedule, ConfigBuildError>

Try to construct a new DownloadSchedule from the fields set in this builder.

Return an error if any required field is missing, or is set to something invalid.

Source

impl DownloadScheduleBuilder

pub fn build_retry_bootstrap( &self, ) -> Result<DownloadSchedule, ConfigBuildError>

Default value for retry_bootstrap in DownloadScheduleConfig.

pub fn build_retry_microdescs( &self, ) -> Result<DownloadSchedule, ConfigBuildError>

Default value for microdesc_bootstrap in DownloadScheduleConfig.