pub struct DirToleranceBuilder { /* private fields */ }Expand description
A builder to create an instance of DirTolerance.
Implementations
Sourceimpl DirToleranceBuilder
impl DirToleranceBuilder
Sourcepub fn pre_valid_tolerance(&mut self, val: Duration) -> &mut Self
pub fn pre_valid_tolerance(&mut self, val: Duration) -> &mut Self
Provide a value for pre_valid_tolerance.
If no value is provided for pre_valid_tolerance, build will use Default::default().
pre_valid_tolerance
For how long before a directory document is valid should we accept it?
Having a nonzero value here allows us to tolerate a little clock skew.
Defaults to 1 day.
Sourcepub fn post_valid_tolerance(&mut self, val: Duration) -> &mut Self
pub fn post_valid_tolerance(&mut self, val: Duration) -> &mut Self
Provide a value for post_valid_tolerance.
If no value is provided for post_valid_tolerance, build will use Default::default().
post_valid_tolerance
For how long after a directory document is valid should we consider it usable?
Having a nonzero value here allows us to tolerate a little clock skew, and makes us more robust to temporary failures for the directory authorities to reach consensus.
Defaults to 3 days (per prop212).
Sourceimpl DirToleranceBuilder
impl DirToleranceBuilder
Sourcepub fn build(&self) -> Result<DirTolerance, ConfigBuildError>
pub fn build(&self) -> Result<DirTolerance, ConfigBuildError>
Try to construct a new DirTolerance from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.