#[non_exhaustive]pub struct DownloadScheduleConfig { /* private fields */ }Expand description
Configuration information for how exactly we download documents from the Tor directory caches.
This type is immutable once constructed. To make one, use
DownloadScheduleConfigBuilder, or deserialize it from a string.
Implementations
Sourceimpl DownloadScheduleConfig
impl DownloadScheduleConfig
Sourcepub fn builder() -> DownloadScheduleConfigBuilder
pub fn builder() -> DownloadScheduleConfigBuilder
Return a new [DownloadScheduleConfig Builder] to construct an instance of this type.
Sourceimpl DownloadScheduleConfig
impl DownloadScheduleConfig
Sourcepub fn retry_bootstrap(&self) -> DownloadSchedule
pub fn retry_bootstrap(&self) -> DownloadSchedule
Top-level configuration for how to retry our initial bootstrap attempt.
Sourcepub fn retry_consensus(&self) -> DownloadSchedule
pub fn retry_consensus(&self) -> DownloadSchedule
Configuration for how to retry a consensus download.
Sourcepub fn retry_certs(&self) -> DownloadSchedule
pub fn retry_certs(&self) -> DownloadSchedule
Configuration for how to retry an authority cert download.
Sourcepub fn retry_microdescs(&self) -> DownloadSchedule
pub fn retry_microdescs(&self) -> DownloadSchedule
Configuration for how to retry a microdescriptor download.