pub struct DownloadScheduleConfigBuilder { /* private fields */ }Expand description
A builder to create an instance of DownloadScheduleConfig.
Implementations
Sourceimpl DownloadScheduleConfigBuilder
impl DownloadScheduleConfigBuilder
Sourcepub fn retry_bootstrap(&mut self) -> &mut DownloadScheduleBuilder
pub fn retry_bootstrap(&mut self) -> &mut DownloadScheduleBuilder
Return a mutable reference to the inner builder for retry_bootstrap.
retry_bootstrap
Top-level configuration for how to retry our initial bootstrap attempt.
Sourcepub fn retry_consensus(&mut self) -> &mut DownloadScheduleBuilder
pub fn retry_consensus(&mut self) -> &mut DownloadScheduleBuilder
Return a mutable reference to the inner builder for retry_consensus.
retry_consensus
Configuration for how to retry a consensus download.
Sourcepub fn retry_certs(&mut self) -> &mut DownloadScheduleBuilder
pub fn retry_certs(&mut self) -> &mut DownloadScheduleBuilder
Return a mutable reference to the inner builder for retry_certs.
retry_certs
Configuration for how to retry an authority cert download.
Sourcepub fn retry_microdescs(&mut self) -> &mut DownloadScheduleBuilder
pub fn retry_microdescs(&mut self) -> &mut DownloadScheduleBuilder
Return a mutable reference to the inner builder for retry_microdescs.
retry_microdescs
Configuration for how to retry a microdescriptor download.
Sourceimpl DownloadScheduleConfigBuilder
impl DownloadScheduleConfigBuilder
Sourcepub fn build(&self) -> Result<DownloadScheduleConfig, ConfigBuildError>
pub fn build(&self) -> Result<DownloadScheduleConfig, ConfigBuildError>
Try to construct a new DownloadScheduleConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.