pub struct NetworkConfigBuilder { /* private fields */ }Expand description
A builder to create an instance of NetworkConfig.
Implementations
Sourceimpl NetworkConfigBuilder
impl NetworkConfigBuilder
Return a mutable reference to the inner builder for authorities.
authorities
List of directory authorities which we expect to perform various operations affecting the overall Tor network.
(If none are specified, we use a default list of authorities shipped with Arti.)
This section cannot be changed in a running Arti client.
The default is to use a set of compiled-in authorities, whose identities and public keys are shipped as part of the Arti source code.
Sourceimpl NetworkConfigBuilder
impl NetworkConfigBuilder
Sourcepub fn build(&self) -> Result<NetworkConfig, ConfigBuildError>
pub fn build(&self) -> Result<NetworkConfig, ConfigBuildError>
Try to construct a new NetworkConfig from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl NetworkConfigBuilder
impl NetworkConfigBuilder
Sourcepub fn fallback_caches(&mut self) -> &mut Vec<FallbackDirBuilder>
pub fn fallback_caches(&mut self) -> &mut Vec<FallbackDirBuilder>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_fallback_caches(&mut self, list: Vec<FallbackDirBuilder>)
pub fn set_fallback_caches(&mut self, list: Vec<FallbackDirBuilder>)
Set the whole list (overriding the default)
Sourcepub fn opt_fallback_caches(&self) -> &Option<Vec<FallbackDirBuilder>>
pub fn opt_fallback_caches(&self) -> &Option<Vec<FallbackDirBuilder>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_fallback_caches_mut(
&mut self,
) -> &mut Option<Vec<FallbackDirBuilder>>
pub fn opt_fallback_caches_mut( &mut self, ) -> &mut Option<Vec<FallbackDirBuilder>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.