pub struct FallbackDirBuilder { /* private fields */ }Expand description
A builder to create an instance of FallbackDir.
Implementations
Sourceimpl FallbackDirBuilder
impl FallbackDirBuilder
Sourcepub fn rsa_identity(&mut self, val: RsaIdentity) -> &mut Self
pub fn rsa_identity(&mut self, val: RsaIdentity) -> &mut Self
Sourcepub fn ed_identity(&mut self, val: Ed25519Identity) -> &mut Self
pub fn ed_identity(&mut self, val: Ed25519Identity) -> &mut Self
Sourceimpl FallbackDirBuilder
impl FallbackDirBuilder
Sourcepub fn build(&self) -> Result<FallbackDir, ConfigBuildError>
pub fn build(&self) -> Result<FallbackDir, ConfigBuildError>
Try to construct a new FallbackDir from the fields set in this builder.
Return an error if any required field is missing, or is set to something invalid.
Sourceimpl FallbackDirBuilder
impl FallbackDirBuilder
Sourcepub fn orports(&mut self) -> &mut Vec<SocketAddr>
pub fn orports(&mut self) -> &mut Vec<SocketAddr>
Access the being-built list (resolving default)
If the field has not yet been set or accessed, the default list will be constructed and a mutable reference to the now-defaulted list of builders will be returned.
Sourcepub fn set_orports(&mut self, list: Vec<SocketAddr>)
pub fn set_orports(&mut self, list: Vec<SocketAddr>)
Set the whole list (overriding the default)
Sourcepub fn opt_orports(&self) -> &Option<Vec<SocketAddr>>
pub fn opt_orports(&self) -> &Option<Vec<SocketAddr>>
Inspect the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &None is returned.
Sourcepub fn opt_orports_mut(&mut self) -> &mut Option<Vec<SocketAddr>>
pub fn opt_orports_mut(&mut self) -> &mut Option<Vec<SocketAddr>>
Mutably access the being-built list (with default unresolved)
If the list has not yet been set, or accessed, &mut None is returned.